pub struct DecodeError {
pub origin: DecodeErrorOrigin,
pub offset: usize,
pub kind: DecodeErrorKind,
pub peer: Option<SocketAddr>,
}Expand description
A decoding failure with an explicit offset coordinate system.
Fields
origin: DecodeErrorOriginCoordinate system in which offset is measured.
offset: usizeZero-based offset in origin.
kind: DecodeErrorKindStructured failure reason.
peer: Option<SocketAddr>Sending peer when decoding occurred at a network boundary.
Implementations
Sourceimpl DecodeError
impl DecodeError
Sourcepub const fn new(offset: usize, kind: DecodeErrorKind) -> Self
pub const fn new(offset: usize, kind: DecodeErrorKind) -> Self
Construct a standalone decode error without peer context.
Sourcepub const fn with_origin(
origin: DecodeErrorOrigin,
offset: usize,
kind: DecodeErrorKind,
) -> Self
pub const fn with_origin( origin: DecodeErrorOrigin, offset: usize, kind: DecodeErrorKind, ) -> Self
Construct a decode error in an explicit coordinate system.
Sourcepub const fn with_peer(self, peer: SocketAddr) -> Self
pub const fn with_peer(self, peer: SocketAddr) -> Self
Attach the sending peer at a network boundary.