#[non_exhaustive]pub enum AuthoritativeEnginePersistenceOperation {
Install,
Restart,
EngineTimeRollover,
}Expand description
The authoritative-engine transition whose durable write failed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Install
Persisting a newly installed engine at boots value 1.
Restart
Persisting the increment performed when loaded state is restarted.
EngineTimeRollover
Persisting an increment after engine time wrapped while running.