pub struct DesSaltPersistenceError { /* private fields */ }Expand description
A failed durable DES generating-engine transition.
Implementations
Sourceimpl DesSaltPersistenceError
impl DesSaltPersistenceError
Sourcepub fn operation(&self) -> DesSaltPersistenceOperation
pub fn operation(&self) -> DesSaltPersistenceOperation
Return the failed transition.
Sourcepub fn previous_engine_boots(&self) -> Option<u32>
pub fn previous_engine_boots(&self) -> Option<u32>
Return the last durable epoch, if this was a restart.
Sourcepub fn attempted_engine_boots(&self) -> u32
pub fn attempted_engine_boots(&self) -> u32
Return the epoch that the callback was asked to persist.
Sourcepub fn persistence_source(&self) -> &(dyn Error + Send + Sync + 'static)
pub fn persistence_source(&self) -> &(dyn Error + Send + Sync + 'static)
Return the concrete persistence callback error.
Sourcepub fn downcast_source_ref<E: Error + 'static>(&self) -> Option<&E>
pub fn downcast_source_ref<E: Error + 'static>(&self) -> Option<&E>
Downcast the callback error to its concrete type.