pub enum Notification {
TrapV1 {
community: Bytes,
trap: TrapV1Pdu,
},
TrapV2c {
community: Bytes,
uptime: u32,
trap_oid: Oid,
varbinds: Vec<VarBind>,
request_id: i32,
},
TrapV3 {
username: Bytes,
context_engine_id: Bytes,
context_name: Bytes,
uptime: u32,
trap_oid: Oid,
varbinds: Vec<VarBind>,
request_id: i32,
},
InformV2c {
community: Bytes,
uptime: u32,
trap_oid: Oid,
varbinds: Vec<VarBind>,
request_id: i32,
},
InformV3 {
username: Bytes,
context_engine_id: Bytes,
context_name: Bytes,
uptime: u32,
trap_oid: Oid,
varbinds: Vec<VarBind>,
request_id: i32,
},
}Expand description
Received SNMP notification.
This enum represents all types of SNMP notifications that can be received:
- SNMPv1 Trap (different PDU structure)
- SNMPv2c/v3 Trap (standard PDU with sysUpTime.0 and snmpTrapOID.0)
- InformRequest (confirmed notification, response will be sent automatically)
Variants
TrapV1
SNMPv1 Trap with unique PDU structure.
TrapV2c
SNMPv2c Trap (unconfirmed notification).
Fields
TrapV3
SNMPv3 Trap (unconfirmed notification).
Fields
InformV2c
InformRequest (confirmed notification) - v2c.
A response is automatically sent when this notification is received.
Fields
InformV3
InformRequest (confirmed notification) - v3.
A response is automatically sent when this notification is received.
Implementations
Sourceimpl Notification
impl Notification