pub struct SaltCounter(/* private fields */);Expand description
Thread-safe salt counter for shared use across multiple encryptions.
Implementations
Sourceimpl SaltCounter
impl SaltCounter
Sourcepub fn from_value(value: u64) -> Self
pub fn from_value(value: u64) -> Self
Create a salt counter initialized to a specific value.
This is primarily for testing purposes.